==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/activity/l10n/ne.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "क्रियाकलापहरू",
    "An error occurred while loading activities" : "क्रियाकलापहरू लोड गर्दा त्रुटि देखापर्यो",
    "No activity yet" : "अझै सम्म कुनै क्रियाकलाप छैन",
    "Load more activities" : "थप क्रियाकलापहरू लोड गर्नुहोस्",
    "Copied!" : "प्रतिलिपि गरियो!",
    "Not supported!" : "समर्थित छैन!",
    "Press ⌘-C to copy." : "प्रतिलिपि गर्न ⌘-C थिच्नुहोस्।",
    "Press Ctrl-C to copy." : "प्रतिलिपि गर्न Ctrl-C थिच्नुहोस्।",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restricted)",
    "in {path}" : "{path} मा",
    "This stream will show events like additions, changes & shares" : "यो स्ट्रिमले घटनाहरू जस्तै एडअनहरू, परिवर्तनहरू र साझा गरिएका कुराहरू देखाउनेछ",
    "There are no events for this filter" : "यस फिल्टरका लागि कुनै घटनाहरू छैनन्",
    "Today" : "आज",
    "Yesterday" : "हिजो",
    "Personal activity feed for %s" : "%sको व्यक्तिगत गतिविधि फिड",
    "Your feed URL is invalid" : "तपाईंको फिड URL अवैध छ",
    "Your settings have been updated." : "तपाईंको सेटिङहरू अद्यावधिक गरिएको छ।",
    "Settings have been updated." : "सेटिङहरू अद्यावधिक गरिएको छ।",
    "Mail" : "पत्र",
    "Stream" : "स्ट्रिम",
    "All activities" : "सबै गतिविधिहरू",
    "By others" : "अरूद्वारा",
    "By you" : "तपाईं द्वारा",
    "\"remote user\"" : "\"रिमोट प्रयोगकर्ता\"",
    "Hello %s" : "नमस्ते %s",
    "Hello %s," : "नमस्ते %s,",
    "There was some activity at %s" : "%s मा केही गतिविधि थियो",
    "_and %n more _::_and %n more _" : ["र थप %n","र %n थप "],
    "Activity notification" : "गतिविधि सूचना",
    ", " : ",",
    "%s and %s" : "%s र %s",
    "Activity" : "गतिविधि",
    "Activity feed" : "गतिविधि पाटि",
    "Send activity emails" : "गतिविधिको इमेलहरू पठाउनुहोस्",
    "Default settings" : "पूर्वनिर्धारित सेटिङहरू",
    "Configure the default activity settings for new users." : "नयाँ प्रयोगकर्ताका लागि पूर्वनिर्धारित गतिविधि सेटिङहरू मिलाउनुहोस्।",
    "List your own actions in the stream" : "पाटिमा आफ्नो कार्यहरू सूचीबद्ध गर्नुहोस्",
    "Notify about your own actions via email" : "इमेल मार्फत आफ्नो कार्यहरूको बारेमा सूचित गर्नुहोस्"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/activity/l10n/ne.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "क्रियाकलापहरू",
    "An error occurred while loading activities" : "क्रियाकलापहरू लोड गर्दा त्रुटि देखापर्यो",
    "No activity yet" : "अझै सम्म कुनै क्रियाकलाप छैन",
    "Load more activities" : "थप क्रियाकलापहरू लोड गर्नुहोस्",
    "Copied!" : "प्रतिलिपि गरियो!",
    "Not supported!" : "समर्थित छैन!",
    "Press ⌘-C to copy." : "प्रतिलिपि गर्न ⌘-C थिच्नुहोस्।",
    "Press Ctrl-C to copy." : "प्रतिलिपि गर्न Ctrl-C थिच्नुहोस्।",
    "Home" : "गृह",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restricted)",
    "in {path}" : "{path} मा",
    "This stream will show events like additions, changes & shares" : "यो स्ट्रिमले घटनाहरू जस्तै एडअनहरू, परिवर्तनहरू र साझा गरिएका कुराहरू देखाउनेछ",
    "There are no events for this filter" : "यस फिल्टरका लागि कुनै घटनाहरू छैनन्",
    "Today" : "आज",
    "Yesterday" : "हिजो",
    "Open file" : "फाईल खोल्नुहोस्",
    "Personal activity feed for %s" : "%sको व्यक्तिगत गतिविधि फिड",
    "Your feed URL is invalid" : "तपाईंको फिड URL अवैध छ",
    "Your settings have been updated." : "तपाईंको सेटिङहरू अद्यावधिक गरिएको छ।",
    "Settings have been updated." : "सेटिङहरू अद्यावधिक गरिएको छ।",
    "Mail" : "पत्र",
    "Stream" : "स्ट्रिम",
    "All activities" : "सबै गतिविधिहरू",
    "By others" : "अरूद्वारा",
    "By you" : "तपाईं द्वारा",
    "\"remote user\"" : "\"रिमोट प्रयोगकर्ता\"",
    "Hello %s" : "नमस्ते %s",
    "Hello %s," : "नमस्ते %s,",
    "There was some activity at %s" : "%s मा केही गतिविधि थियो",
    "_and %n more _::_and %n more _" : ["र थप %n","र %n थप "],
    "Activity notification" : "गतिविधि सूचना",
    ", " : ",",
    "%s and %s" : "%s र %s",
    "Activity" : "गतिविधि",
    "Activity feed" : "गतिविधि पाटि",
    "Send activity emails" : "गतिविधिको इमेलहरू पठाउनुहोस्",
    "Default settings" : "पूर्वनिर्धारित सेटिङहरू",
    "Configure the default activity settings for new users." : "नयाँ प्रयोगकर्ताका लागि पूर्वनिर्धारित गतिविधि सेटिङहरू मिलाउनुहोस्।",
    "List your own actions in the stream" : "पाटिमा आफ्नो कार्यहरू सूचीबद्ध गर्नुहोस्",
    "Notify about your own actions via email" : "इमेल मार्फत आफ्नो कार्यहरूको बारेमा सूचित गर्नुहोस्",
    "You need to set up your email address before you can receive notification emails." : "अग्रसूचना ईमेलहरू प्राप्त गर्नु अघि तपाईंले आफ्नो ईमेल ठेगाना सेट अप गर्न आवश्यक छ।",
    "Send emails:" : "इ-मेलहरू पठाउनुहोस्:",
    "As soon as possible" : "सकेसम्म चाँडै",
    "Hourly" : "घण्टा",
    "Daily" : "दैनिक",
    "Weekly" : "साप्ताहिक"
},
"nplurals=2; plural=(n != 1);");
